# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .athena_assistant.client import AsyncAthenaAssistantClient, AthenaAssistantClient
from .structured_data_extractor.client import AsyncStructuredDataExtractorClient, StructuredDataExtractorClient


class AgentsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.athena_assistant = AthenaAssistantClient(client_wrapper=self._client_wrapper)
        self.structured_data_extractor = StructuredDataExtractorClient(client_wrapper=self._client_wrapper)


class AsyncAgentsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.athena_assistant = AsyncAthenaAssistantClient(client_wrapper=self._client_wrapper)
        self.structured_data_extractor = AsyncStructuredDataExtractorClient(client_wrapper=self._client_wrapper)
